EnumStr

Trait EnumStr 

pub trait EnumStr: Sized {
    // Required methods
    fn as_name(&self) -> &'static str;
    fn as_aliases(&self) -> &'static [&'static str];
}
Convert between enum and string.

Derive this trait on unit enums via #[derive(EnumStr)].

Required Methods

fn as_name(&self) -> &'static str

Returns the primary string name of this variant.

fn as_aliases(&self) -> &'static [&'static str]

Returns all string names and aliases of this variant.

The first element is always the primary name (returned by as_name). Subsequent elements are aliases added via alias_all and alias.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors